@@ -45,9 +45,12 @@ class _SealedRelatedQuerySet(QuerySet):
 
 
 class SealedPrefetchMixin(object):
+    def _get_default_prefetch_queryset(self):
+        return self.get_queryset()
+
     def get_prefetch_queryset(self, instances, queryset=None):
         if queryset is None:
-            queryset = self.get_queryset()
+            queryset = self._get_default_prefetch_queryset()
         if getattr(instances[0]._state, 'sealed', False) and isinstance(queryset, SealableQuerySet):
             queryset = queryset.seal()
         return super().get_prefetch_queryset(instances, queryset)
@@ -75,6 +78,12 @@ def seal_related_queryset(queryset, warning):
 
 def create_sealable_related_manager(related_manager_cls, field_name):
     class SealableRelatedManager(SealedPrefetchMixin, related_manager_cls):
+        def _get_default_prefetch_queryset(self):
+            # By-pass `related_manager_cls.get_queryset()` as that's the default
+            # for dynamically created manager's `get_prefetch_queryset` when
+            # no `queryset` is specified.
+            return super(related_manager_cls, self).get_queryset()
+
         def get_queryset(self):
             if getattr(self.instance._state, 'sealed', False):
                 try:
